.. _generate_hic:

======================
Generate Hi-C matrices
======================

.. toctree::
   :maxdepth: 2

    fanc auto: Automated generation of Hi-C matrices <fanc-generate-hic/fanc_auto>
    Individual pipeline steps <fanc-generate-hic/fanc_modular_steps>
    Helper tools <fanc-generate-hic/fanc_helpers>
    Configuration options <fanc-generate-hic/fanc_config>
